arXiv Multi-Citations

## Introduction

Recurrent models typically factor computation along the symbol positions of the input and output sequences, as explored in prior work [35, 2, 5]. Some models use a single citation [12] while others reference two works [7, 9].

## References

- [2] Dzmitry Bahdanau, Kyunghyun Cho, and Yoshua Bengio. Neural machine translation by jointly learning to align and translate. CoRR, 2014.
- [5] Junyoung Chung, Caglar Gulcehre, KyungHyun Cho, and Yoshua Bengio. Empirical evaluation of gated recurrent neural networks on sequence modeling. 2014.
- [7] Jonas Gehring, Michael Auli, David Grangier, Denis Yarats, and Yann N. Dauphin. Convolutional sequence to sequence learning. 2017.
- [9] Alex Graves. Generating sequences with recurrent neural networks. 2013.
- [12] Sepp Hochreiter and Jurgen Schmidhuber. Long short-term memory. 1997.
- [35] Ilya Sutskever, Oriol Vinyals, and Quoc V. Le. Sequence to sequence learning with neural networks. 2014.